%global         common_desc     %{expand:
Impacket is a collection of Python classes focused on providing access to network packets. Impacket
allows Python developers to craft and decode network packets in simple and consistent manner. It is
highly effective when used in conjunction with a packet capture utility or package such as Pcapy.
Packets can be constructed from scratch, as well as parsed from raw data. Furthermore, the object
oriented API makes it simple to work with deep protocol hierarchies.}

%global __requires_exclude ldapdomaindump|flask|httplib2
%global         gitname         impacket
%global         pkgver          %%(echo %{version} | sed 's/\\./_/g')

Summary:        Collection of Python classes providing access to network packets
Name:           python-impacket
Version:        0.11.0
Release:        1%{?dist}
License:        ASL 1.1 and zlib
URL:            https://github.com/SecureAuthCorp/impacket
Source0:        %{url}/releases/download/%{gitname}_%{pkgver}/%{gitname}-%{version}.tar.gz

BuildRequires:  sed grep python%{python3_pkgversion}-devel python%{python3_pkgversion}-setuptools
BuildArch:      noarch

%description
%{common_desc}

%package -n python%{python3_pkgversion}-%{gitname}
Summary:        Collection of Python classes providing access to network packets
Requires:       python%{python3_pkgversion}-pycryptodomex python%{python3_pkgversion}-ldap3
Requires:       python%{python3_pkgversion}-pyasn1 python%{python3_pkgversion}-pyOpenSSL
Provides:       impacket = %{version}-%{release}
Recommends:     python%{python3_pkgversion}-pcapy
Recommends:     python%{python3_pkgversion}-httplib2
Recommends:     python%{python3_pkgversion}-flask

%description -n python%{python3_pkgversion}-%{gitname}
Python3 package of %{name}. %{common_desc}

%prep
%autosetup -p 1 -n %{gitname}-%{version}

sed -i -e 's|#!/usr/bin/env python|#!/usr/bin/python3|' \
    impacket/mqtt.py \
    impacket/examples/ntlmrelayx/servers/socksserver.py

sed -i -e 's|^import uncrc32|from impacket.examples import uncrc32|;' examples/nmapAnswerMachine.py

%build
%py3_build

%install
%py3_install
pushd %{buildroot}%{_bindir}
for I in *.py ; do
    BASENAME=$(basename "$I" .py)
    mv "$I" "${BASENAME}-%{python3_version}"
    ln -s "${BASENAME}-%{python3_version}" "${BASENAME}-3"
done
popd

pushd %{buildroot}%{_bindir}
    for I in *-3 ; do
        BASENAME=$(basename "$I" "-3" )
        ln -s "${I}" "${BASENAME}.py"
    done
popd

rm -f %{buildroot}%{_defaultdocdir}/%{name}/LICENSE

%check
PYTHONPATH=$BUILD_ROOT/usr/lib/python%{python3_version}/site-packages/ python3 -c \
    'import impacket.ImpactPacket ; impacket.ImpactPacket.IP().get_packet()'

%files -n       python%{python3_pkgversion}-%{gitname}
%license        LICENSE
%doc            ChangeLog.md README.md
%{python3_sitelib}/%{gitname}/
%{python3_sitelib}/%{gitname}*.egg-info
%{_bindir}/*-%{python3_version}
%{_bindir}/*-3
%{_bindir}/*.py
%exclude %{_defaultdocdir}/%{gitname}
%exclude %{_defaultdocdir}/%{gitname}/README.md

%changelog
* Mon Oct 09 2023 kianli <kianli@tencent.com> - 0.11.0-1
- Upgrade to 0.11.0
- Fix CVE-2020-17049

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.9.23-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.9.23-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.9.23-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.9.23-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 29 2023 Shuo Wang <abushwang@tencent.com> - 0.9.23-1
- initial build
